@@ -1,4 +1,4 @@
-
+import pytest
 import qcelemental as qcel
 from numpy.testing import assert_allclose
 
@@ -8,6 +8,8 @@ from psiresp.orientation import Orientation
 from psiresp.qm import QMEnergyOptions
 from psiresp.tests.utils import load_gamess_esp
 
+pytest.importorskip("psi4")
+
 
 def test_compute_esp_regression(fractal_client):
     # setup
@@ -30,14 +32,14 @@ def test_compute_esp_regression(fractal_client):
     assert orientation.energy < 0
 
 
-def test_compute_esp(methylammonium, fractal_client, job_grids, job_esps):
-    orientation = methylammonium.conformers[0].orientations[0]
+def test_compute_esp(methylammonium_empty, fractal_client, job_grids, job_esps):
+    orientation = methylammonium_empty.conformers[0].orientations[0]
     mol_ids = fractal_client.add_molecules([orientation.qcmol])
     record = fractal_client.query_results(id=mol_ids)[0]
 
     fname = orientation.qcmol.get_hash()
     orientation.compute_grid()
-    assert_allclose(orientation.grid, job_grids[fname])
+    assert_allclose(orientation.grid, job_grids[fname], atol=5e-9)
 
     orientation.compute_esp_from_record(record)
-    assert_allclose(orientation.esp, job_esps[fname])
+    assert_allclose(orientation.esp, job_esps[fname], atol=5e-9)
